@@ -1,9 +1,9 @@
 
 class ZiggeoConfig:
     def __init__(self):
-        self.server_api_url = "https://srvapi.ziggeo.com"
+        self.server_api_url = "https://srv-api.ziggeo.com"
 
-        self.regions = {"r1":"https://srvapi-eu-west-1.ziggeo.com"}
+        self.regions = {"r1":"https://srv-api-eu-west-1.ziggeo.com"}
 
         self.api_url = "https://api-us-east-1.ziggeo.com"
 
